@@ -1559,7 +1559,7 @@ class Plot(object):
     norm : float
       normalize the y values by the given number (i.e. y=y/norm)
       Default: `None` (i.e. no normalisation)
-      
+
     '''
 
     print("PLOT: plot_abunrad ...")
@@ -1646,7 +1646,7 @@ class Plot(object):
     norm : float
       normalize the y values by the given number (i.e. y=y/norm)
       Default: `None` (i.e. no normalisation)
-      
+
     '''
 
     print("PLOT: plot_abun_midp ...")
@@ -2178,7 +2178,7 @@ class Plot(object):
     return self._closefig(fig)
 
   def plot_line_origin(self,model,lineIdents,field,label="value",boxcolors=None,showBox=True,showRadialLines=True,boxlinewidths=1.5,
-                       boxlinestyles=None,boxhatches=None,lineLabels=None,showLineLabels=True,lineLabelsAlign="left",zlog=True,
+                       boxlinestyles=None,boxhatches=None,lineLabels=None,showLineLabels=True,lineLabelsFontsize=6.0,lineLabelsAlign="left",zlog=True,
                 zlim=[None,None],zr=True,clevels=None,clabels=None,contour=False,
                 extend="neither",oconts=None,nbins=70,
                 bgcolor=None,cb_format="%.1f",scalexy=[1,1],patches=None,
@@ -2208,8 +2208,6 @@ class Plot(object):
       the widths of the line for each box showing the line origin. Can be a
       scalar, in that case all boxes have the same linewidth
 
-
-    TODO: possibility to pass Axes object like in most other plots.
     '''
     if boxcolors is None:
       boxcolors=[self.pcolors["red"],self.pcolors["orange"],self.pcolors["brown"],
@@ -2319,16 +2317,18 @@ class Plot(object):
         else:
           label="$"+spnToLatex(idline[0])+"$ "+str(idline[1])
 
+        # FIXME: quick and dirty, ref fontsize =6.0
+        vpos=ibox/(18.0-(lineLabelsFontsize/6.0-1.0)*12.0)
         if lineLabelsAlign=="right":
-          ax.text(0.95,0.92-ibox/18.0,label,
+          ax.text(0.95,0.92-vpos,label,
                 horizontalalignment='right',
-                verticalalignment='bottom',fontsize=6.0,
+                verticalalignment='bottom',fontsize=lineLabelsFontsize,
                 transform=ax.transAxes,color=boxcolors[ibox],
                 bbox=dict(boxstyle='square,pad=0.1',fc='white',ec='none'))
         else:
-          ax.text(0.02,0.92-ibox/18.0,label,
+          ax.text(0.02,0.92-vpos,label,
                 horizontalalignment='left',
-                verticalalignment='bottom',fontsize=6.0,
+                verticalalignment='bottom',fontsize=lineLabelsFontsize,
                 transform=ax.transAxes,color=boxcolors[ibox],
                 bbox=dict(boxstyle='square,pad=0.1',fc='white',ec='none'))
         ibox+=1
