@@ -166,6 +166,13 @@ class PlotModels(object):
 
     If self.pdf is None than nothing is done and the figure is returend
 
+    Parameters
+    ==========
+
+    fig : :class:`~matplotlib.figure.Figure`
+      A matplotliblib Figure object that will be saved in `self.pdf` if it exists
+      or just returned again.
+
     '''
 
     # trans=mpl.rcParams['savefig.transparent']
