@@ -96,10 +96,10 @@ def read_tdep_file(filename):
   Currently this file does not include the initial abundances!
 
   .. todo::
-
-    This is quick and dirty. However, the problem is more in |prodimo| because
-    it is unclear what file is for what and when (depending on parameter configuration)
-    which file is written.
+    * This is quick and dirty. However, the problem is more in |prodimo| because
+      it is unclear what file is for what and when (depending on parameter configuration)
+      which file is written.
+    * This does not deal with the two e- like in the normal mode. This is inconsistent.
 
   Returns
   -------
@@ -144,6 +144,12 @@ def _read_species(filename):
 
   species=[strr.strip() for strr in f.readlines()]
   species[species.index("HN2+")]="N2H+"
+
+  # quick an dirty fix for el_is_sp. If the first and last element are e-
+  # remove the last one
+  if species[0]=="e-" and species[-1]=="e-":
+    del(species[-1])
+
   f.close()
 
   return species
@@ -268,6 +274,9 @@ def read_mc(filename="mc_output.txt",directory=".",agesfile="mc_ages.txt",specie
     # make ages first index, species second
     print("READ: Reading File: ",directory+"/"+filename," ...")
     mc.abundances=np.transpose(np.loadtxt(directory+"/"+filename))
+    # FIXME: quick an dirty fix for el_is_sp true if the len of species is smaller
+    if (len(mc.species)<mc.abundances.shape[1]):
+      mc.abundances=np.delete(mc.abundances,-1,axis=1)
 
   return mc
 
